Module streams

Module streams 

Re-exports

pub use p2panda_core::cbor::DecodeError;

Structs

EphemeralMessage
Message coming from an ephemeral stream subscription.
EphemeralStreamPublisher
Publish messages into an ephemeral topic stream.
EphemeralStreamSubscription
Subscription to messages arriving from an ephemeral topic stream.
ProcessedOperation
Processed operation with application message coming from a topic stream.
PublishFuture
Future which can be awaited to find out when a locally published operation has finished processing.
StreamPublisher
Publish messages into a topic stream.
StreamSubscription
Subscription to events arriving from a topic stream.
SyncError
Error occurred during a sync session.

Enums

AckedError
Acknowledgment of event failed due to critical error.
EphemeralPublishError
Error occurred when publishing a message to ephemeral topic stream.
PublishError
Error occurred when creating operation and publishing it to topic stream.
ReplayError
Topic stream could not re-play events due to an internal error.
SessionPhase
Which phase of a sync session an operation arrived in.
Source of a processed operation.
StreamEvent
Operations with application messages, system events and errors coming from a topic stream subscription.
StreamFrom
Determines the starting point of a subscription stream.
SystemEvent
System event.