Re-exports
pub use p2panda_core::cbor::DecodeError;
Structs
- Ephemeral
Message - Message coming from an ephemeral stream subscription.
- Ephemeral
Stream Publisher - Publish messages into an ephemeral topic stream.
- Ephemeral
Stream Subscription - Subscription to messages arriving from an ephemeral topic stream.
- Processed
Operation - Processed operation with application message coming from a topic stream.
- Publish
Future - Future which can be awaited to find out when a locally published operation has finished processing.
- Stream
Publisher - Publish messages into a topic stream.
- Stream
Subscription - Subscription to events arriving from a topic stream.
- Sync
Error - Error occurred during a sync session.
Enums
- Acked
Error - Acknowledgment of event failed due to critical error.
- Ephemeral
Publish Error - Error occurred when publishing a message to ephemeral topic stream.
- Publish
Error - Error occurred when creating operation and publishing it to topic stream.
- Replay
Error - Topic stream could not re-play events due to an internal error.
- Session
Phase - Which phase of a sync session an operation arrived in.
- Source
- Source of a processed operation.
- Stream
Event - Operations with application messages, system events and errors coming from a topic stream subscription.
- Stream
From - Determines the starting point of a subscription stream.
- System
Event - System event.